# SVVAMP


[![PyPI Status](https://img.shields.io/pypi/v/svvamp.svg)](https://pypi.python.org/pypi/svvamp)
[![Build Status](https://github.com/francois-durand/svvamp/actions/workflows/build.yml/badge.svg?branch=master)](https://github.com/francois-durand/svvamp/actions?query=workflow%3Abuild)
[![Documentation Status](https://github.com/francois-durand/svvamp/actions/workflows/docs.yml/badge.svg?branch=master)](https://github.com/francois-durand/svvamp/actions?query=workflow%3Adocs)
[![License](https://img.shields.io/github/license/francois-durand/svvamp)](https://github.com/francois-durand/svvamp/blob/master/LICENSE)
[![Code Coverage](https://codecov.io/gh/francois-durand/svvamp/branch/master/graphs/badge.svg)](https://codecov.io/gh/francois-durand/svvamp/tree/master)

Simulator of Various Voting Algorithms in Manipulating Populations


- Free software: GNU General Public License v3
- Code: https://github.com/francois-durand/svvamp.
- Documentation: https://francois-durand.github.io/svvamp/.


## Features

- Define profiles of voters with preferences over a set of candidates. Preferences can be generated by several probabilistic models, entered manually or imported from an external file.
- Compute the result of several voting rules (ballots, winner, scores, etc).
- Decide Condorcet notions.
- Decide Independence of Irrelevant Alternatives.
- Decide Individual Manipulation.
- Decide Coalitional Manipulation and variants: Ignorant-Coalition Manipulation, Trivial Manipulation and Unison Manipulation.

## Credits

This package was created with [Cookiecutter][CC] and the [Package Helper 3][PH3] project template.

[CC]: https://github.com/audreyr/cookiecutter
[PH3]: https://balouf.github.io/package-helper-3/
